==> depp_test-0.3.9.tar.gz: depp_test-0.3.9/depp/default_config.py <==
default_config = \
{'exp_name': '',
'data_dir': '',
'summary_dir': 'summary',
'model_dir': 'model',
'distance_mode': 'L2',
'embedding_size': None,
'sequence_length': 0,
'h_channel': 8,
'beta_ratio': 50000,

'tau_pres_end_epoch': 5,
'start_epoch': 0,
'epoch': 5001,
'batch_size': 32,
'cp': 1.0,
'resblock_num': 1,

'lr': 1e-4,
'lr_decay': 2000,
'backbone_tree_file': None,
'backbone_seq_file': None,
'query_seq_file': '',
'weighted_method': 'square_root_fm',
'distance_alpha': 1e5,
'dis_loss_ratio': 1.0,
'plot_freq': 1000,
'save_data_freq': 1000,
'save_model_freq': 3000,
'print_freq': 1000,
'stop_par': 200,
'gpus': [0],
'plot_all_freqdistance_depp.sh -q ./seq/query_seq/query_seq.fa -b ./seq/backbone_seq/backbone_seq.fa -m model/epoch\=599.ckpt -t tree/backbone_tree/backbone.newick -o dis_mat/': 2000,
'lr_update_freq': 500,
'bar_update_freq': 1,
'patience': 500000,
'model_path': '',
'outdir': 'depp_distance',
'num_worker': 4,
'replicate_seq': False,
'gap_encode': 0.25,
'jc_correct': False,
'recon_model_path': None,
'query_dist': False,
'val_freq': 50000000,
'ae_train_epoch': 300,
'seq_h_ratio': 0.5,
'backbone_emb': None,
'backbone_gap': None,
'backbone_id': None,
'recon_backbone_emb':None,
'load_model': None,
'add_random_mask': False,
'get_representative_emb': False,
'start_model_idx': -1,
'only_class': False,
'end_model_idx': None,
'cluster_num': 1,
'seqdir': None,
'use_cluster': None,
'classifier_seqdir': None,
'use_multi_class': None,
'prob_thr': 5,
'cluster_corr': None
}

#def get_cfg_defaults():
#    """Get a yacs CfgNode object with default values for my_project."""
#    # Return a clone so that the defaults will not be altered
#    # This is for the "local variable" use pattern
#    return _C.clone()

==> depp_test-0.4.0.tar.gz: depp_test-0.4.0/depp/default_config.py <==
default_config = \
{'exp_name': '',
'data_dir': '',
'summary_dir': 'summary',
'model_dir': 'model',
'distance_mode': 'L2',
'embedding_size': None,
'sequence_length': 0,
'h_channel': 8,
'beta_ratio': 50000,

'tau_pres_end_epoch': 5,
'start_epoch': 0,
'epoch': 5001,
'batch_size': 32,
'cp': 1.0,
'resblock_num': 1,

'lr': 1e-4,
'lr_decay': 2000,
'backbone_tree_file': None,
'backbone_seq_file': None,
'query_seq_file': '',
'weighted_method': 'square_root_fm',
'distance_alpha': 1e5,
'dis_loss_ratio': 1.0,
'plot_freq': 1000,
'save_data_freq': 1000,
'save_model_freq': 3000,
'print_freq': 1000,
'stop_par': 200,
'gpus': [0],
'plot_all_freqdistance_depp.sh -q ./seq/query_seq/query_seq.fa -b ./seq/backbone_seq/backbone_seq.fa -m model/epoch\=599.ckpt -t tree/backbone_tree/backbone.newick -o dis_mat/': 2000,
'lr_update_freq': 500,
'bar_update_freq': 1,
'patience': 500000,
'model_path': '',
'outdir': 'depp_distance',
'num_worker': 4,
'replicate_seq': False,
'gap_encode': 0.25,
'jc_correct': False,
'recon_model_path': None,
'query_dist': False,
'val_freq': 50000000,
'ae_train_epoch': 300,
'seq_h_ratio': 0.5,
'backbone_emb': None,
'backbone_gap': None,
'backbone_id': None,
'recon_backbone_emb':None,
'load_model': None,
'add_random_mask': False,
'get_representative_emb': False,
'start_model_idx': -1,
'only_class': False,
'end_model_idx': None,
'cluster_num': 1,
'seqdir': None,
'use_cluster': None,
'classifier_seqdir': None,
'use_multi_class': None,
'prob_thr': 5,
'cluster_corr': None,
'train_mode': 'partial'
}

#def get_cfg_defaults():
#    """Get a yacs CfgNode object with default values for my_project."""
#    # Return a clone so that the defaults will not be altered
#    # This is for the "local variable" use pattern
#    return _C.clone()
